==> mx-usb-unmounter_24.09.tar.xz: BUILD/translations/mx-usb-unmounter_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="186"/>
        <location filename="../mainwindow.cpp" line="290"/>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>MX USB Unmounter</source>
        <translation>MX-Desmontar dispositivos USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="52"/>
        <source>Double-Click to Unmount</source>
        <translation>Duplo clique para desmontar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="118"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="153"/>
        <source>No Removable Device</source>
        <translation>Nenhum dispositivo removível</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Other partitions still mounted on device</source>
        <translation>Ainda estão montadas outras partições no dispositivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="188"/>
        <source>Unmounting %1</source>
        <translation>A desmontar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>%1 is Safe to Remove</source>
        <translation>É seguro remover %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Unable to unmount, device in use</source>
        <translation>Não foi possível desmontar. O dispositivo está em utilização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>List Devices</source>
        <translation>Listar dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Autostart has been disabled.</source>
        <translation>O arranque automático foi desactivado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Failed to disable autostart.</source>
        <translation>Ocorreu uma falha ao activar o arranque automático.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Autostart Disabled</source>
        <translation>Arranque automático desactivado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Enable Autostart</source>
        <translation>Activar o arranque automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>Autostart has been enabled.</source>
        <translation>O arranque automático foi activado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>Failed to enable autostart.</source>
        <translation>Ocorreu uma falha ao activar o arranque automático.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Autostart Enabled</source>
        <translation>Arranque automático activado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Disable Autostart</source>
        <translation>Desactivar o arranque automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Unmount</source>
        <translation>Desmontar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>About MX USB Unmounter</source>
        <translation>Acerca do MX Desmontar dispositivos USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Quickly Unmount Removable Media</source>
        <translation>Desmontar rapidamente o dispositivos removíveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
</TS>

==> mx-usb-unmounter_24.09.02.tar.xz: BUILD/translations/mx-usb-unmounter_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="94"/>
        <location filename="../mainwindow.cpp" line="203"/>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>MX USB Unmounter</source>
        <translation>MX-Desmontar dispositivos USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="52"/>
        <source>Double-Click to Unmount</source>
        <translation>Duplo clique para desmontar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>No Removable Device</source>
        <translation>Nenhum dispositivo removível</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>Other partitions still mounted on device</source>
        <translation>Ainda estão montadas outras partições no dispositivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Unmounting %1</source>
        <translation>A desmontar %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>%1 is Safe to Remove</source>
        <translation>É seguro remover %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Unable to unmount, device in use</source>
        <translation>Não foi possível desmontar. O dispositivo está em utilização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>List Devices</source>
        <translation>Listar dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Always show icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Hide icon when not in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>Autostart has been disabled.</source>
        <translation>O arranque automático foi desactivado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>Failed to disable autostart.</source>
        <translation>Ocorreu uma falha ao activar o arranque automático.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <source>Autostart Disabled</source>
        <translation>Arranque automático desactivado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Enable Autostart</source>
        <translation>Activar o arranque automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>Autostart has been enabled.</source>
        <translation>O arranque automático foi activado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>Failed to enable autostart.</source>
        <translation>Ocorreu uma falha ao activar o arranque automático.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Autostart Enabled</source>
        <translation>Arranque automático activado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <source>Disable Autostart</source>
        <translation>Desactivar o arranque automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Unmount</source>
        <translation>Desmontar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <source>About MX USB Unmounter</source>
        <translation>Acerca do MX Desmontar dispositivos USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Quickly Unmount Removable Media</source>
        <translation>Desmontar rapidamente o dispositivos removíveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Application icon will stay visible all the time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Application icon is now hidden and will reappear when a new device is connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Application icon will be hidden when there are no devices plugged in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Icon Visibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
</TS>
